@@ -5,7 +5,7 @@ from typing import List
 
 class EKSNodeGroupRemoteAccess(BaseResourceCheck):
     def __init__(self):
-        name = "Ensure Amazon EKS Node group has implict SSH access from 0.0.0.0/0"
+        name = "Ensure Amazon EKS Node group has implicit SSH access from 0.0.0.0/0"
         id = "CKV_AWS_100"
         supported_resources = ['aws_eks_node_group']
         categories = [CheckCategories.KUBERNETES]
